@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: cmd89.c 577 2004-04-10 15:30:22Z roms $ */
+/* $Id: cmd89.c 788 2004-09-19 10:54:50Z roms $ */
 
 /*  libticalcs - Ti Calculator library, a part of the TiLP project
  *  Copyright (C) 1999-2004  Romain Lievin
@@ -32,13 +32,18 @@
 #include "update.h"
 #include "printl.h"
 
-// Shares some commands between TI89/92+/V200
+#ifdef __WIN32__
+#pragma warning( disable : 4761 4244)
+#endif
+
+// Shares some commands between TI89/92+/V200/TI89 Titanium
 extern int ticalcs_calc_type;
 
 static uint8_t pc_ti9x(void)
 {
   switch (ticalcs_calc_type) {
   case CALC_TI89:
+  case CALC_TI89T:
     return PC_TI89;
     break;
   case CALC_TI92P:
