@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: ti73.c 613 2004-04-17 14:54:37Z roms $ */
+/* $Id: ti73.c 805 2004-10-06 17:54:56Z roms $ */
 
 /*  libticalcs - Ti Calculator library, a part of the TiLP project
  *  Copyright (C) 1999-2004  Romain Lievin
@@ -20,15 +20,16 @@
  */
 
 /*
-  This unit provides TI73/TI83+ support.
+  This unit provides TI73/TI83+/TI84+ support.
 */
 
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
-#include <unistd.h>
+//#include <unistd.h>
+
+#include "gettext.h"
 
-#include "intl2.h"
 #include "headers.h"
 #include "externs.h"
 #include "update.h"
@@ -39,6 +40,10 @@
 #include "pause.h"
 #include "printl.h"
 
+#ifdef __WIN32__
+#pragma warning( disable : 4761 4244)
+#endif
+
 // Screen coordinates of the TI83+
 #define TI73_ROWS  64
 #define TI73_COLS  96
@@ -481,6 +486,11 @@ int ti73_send_flash(const char *filename, int mask_mode)
     //TRYF(ti73_send_RDY());
     //TRYF(ti73_recv_ACK(NULL));
   }
+  else if(ticalcs_calc_type == CALC_TI84P)
+	  {
+		  UNLOCK_TRANSFER();
+		  return ERR_VOID_FUNCTION;
+	  }
 
   TRYF(ti8x_read_flash_file(filename, &content));
 
@@ -581,8 +591,8 @@ exit:
   return 0;
 }
 
-#define DUMP_ROM73_FILE "dumprom.83p"
-#define ROMSIZE 512		// 512KB
+#define DUMP_ROM73_FILE "dumprom.8Xp"
+#define ROMSIZE 512		// 512KB (TI83+) or 1MB (TI84+) or 2MB (SilverEdition)
 
 int ti73_dump_rom(const char *filename, int mask_mode)
 {
@@ -595,7 +605,8 @@ int ti73_dump_rom(const char *filename, int mask_mode)
   FILE *f, *file;
   uint16_t checksum, sum;
   int err;
-  int b = 0;;
+  int b = 0;
+  //int ROMSIZE = (ticalcs_calc_type == CALC_TI84P) ? 1024 : 512;
 
   printl2(0, _("ROM dumping...\n"));
 
@@ -650,6 +661,8 @@ int ti73_dump_rom(const char *filename, int mask_mode)
       fprintf(file, "%c", data);
       sum += data;
 
+	  printf("%02X ", data);
+
       update->count = j;
       update_pbar();
       if (update->cancel)
