@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: ti89.c 577 2004-04-10 15:30:22Z roms $ */
+/* $Id: ti89.c 792 2004-09-19 14:09:31Z roms $ */
 
 /*  libticalcs - Ti Calculator library, a part of the TiLP project
  *  Copyright (C) 1999-2004  Romain Lievin
@@ -20,15 +20,16 @@
  */
 
 /*
-  This unit provides TI89/TI92+/V200 support.
+  This unit provides TI89/TI92+/V200/TI89 Titanium support.
 */
 
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
-//#include <unistd.h>
+#include <unistd.h>
+
+#include "gettext.h"
 
-#include "intl2.h"
 #include "headers.h"
 #include "externs.h"
 #include "update.h"
@@ -109,6 +110,7 @@ int ti89_screendump(uint8_t ** bitmap, int mask_mode,
   sc->height = TI89_ROWS;
   switch (ticalcs_calc_type) {
   case CALC_TI89:
+  case CALC_TI89T:
     sc->clipped_width = TI89_COLS_VISIBLE;
     sc->clipped_height = TI89_ROWS_VISIBLE;
     break;
@@ -142,7 +144,7 @@ int ti89_screendump(uint8_t ** bitmap, int mask_mode,
   UNLOCK_TRANSFER();
 
   // Clip the unused part of the screen (nethertheless useable witha asm prog)
-  if ((ticalcs_calc_type == CALC_TI89)
+  if (((ticalcs_calc_type == CALC_TI89) || (ticalcs_calc_type == CALC_TI89T))
       && (mask_mode == CLIPPED_SCREEN)) {
     int i, j, k;
 
@@ -191,7 +193,7 @@ int ti89_directorylist(TNode ** tree, uint32_t * memory)
   t_node_append(*tree, vars);
   t_node_append(*tree, apps);
 
-  for (j = 4; j < block_size;) {
+  for (j = 4; j < (int)block_size;) {
     TiVarEntry *fe = calloc(1, sizeof(TiVarEntry));
     TNode *node;
 
@@ -218,7 +220,7 @@ int ti89_directorylist(TNode ** tree, uint32_t * memory)
   }
 
   // get list of variables into each folder
-  for (i = 0; i < t_node_n_children(vars); i++) {
+  for (i = 0; i < (int)t_node_n_children(vars); i++) {
     TNode *folder = t_node_nth_child(vars, i);
     char *folder_name = ((TiVarEntry *) (folder->data))->name;
 
@@ -239,7 +241,7 @@ int ti89_directorylist(TNode ** tree, uint32_t * memory)
     TRYF(ti89_recv_EOT());
     TRYF(ti89_send_ACK());
 
-    for (j = 4 + 14 + extra; j < block_size;) {
+    for (j = 4 + 14 + extra; j < (int)block_size;) {
       TiVarEntry *ve = calloc(1, sizeof(TiVarEntry));
       TNode *node;
 
@@ -575,6 +577,11 @@ int ti89_send_flash(const char *filename, int mask_mode)
   printl2(0, _("FLASH app/os size: %i bytes.\n"), ptr->data_length);
 
   if (ptr->data_type == TI89_AMS) {
+	  if(ticalcs_calc_type == CALC_TI89T)
+	  {
+		  UNLOCK_TRANSFER();
+		  return ERR_VOID_FUNCTION;
+	  }
     TRYF(ti89_send_RTS(ptr->data_length, ptr->data_type, ""));
   } else {
     TRYF(ti89_send_RTS(ptr->data_length, ptr->data_type, ptr->name));
@@ -676,7 +683,7 @@ int ti89_recv_flash(const char *filename, int mask_mode, TiVarEntry * ve)
 }
 
 #define DUMP_ROM89_FILE "dumprom.89z"
-#define ROMSIZE (2*1024)	// 2MB
+//#define ROMSIZE (2*1024)	// 2MB or 4MB (Titanium)
 
 int ti89_dump_rom(const char *filename, int mask_mode)
 {
@@ -688,6 +695,8 @@ int ti89_dump_rom(const char *filename, int mask_mode)
   int pad;
   FILE *f, *file;
   uint16_t checksum, sum;
+  int ROMSIZE = (ticalcs_calc_type == CALC_TI89T) || 
+  				(ticalcs_calc_type == CALC_V200) ? 4*1024 : 2*1024;
 
   printl2(0, _("ROM dumping...\n"));
 
@@ -716,13 +725,13 @@ int ti89_dump_rom(const char *filename, int mask_mode)
   TRY(ti89_send_key('i'));
   TRY(ti89_send_key('n'));
   TRY(ti89_send_key('\\'));
+  TRY(ti89_send_key('r'));
+  TRY(ti89_send_key('o'));
+  TRY(ti89_send_key('m'));
   TRY(ti89_send_key('d'));
   TRY(ti89_send_key('u'));
   TRY(ti89_send_key('m'));
   TRY(ti89_send_key('p'));
-  TRY(ti89_send_key('r'));
-  TRY(ti89_send_key('o'));
-  TRY(ti89_send_key('m'));
   TRY(ti89_send_key(KEY89_LP));
   TRY(ti89_send_key(KEY89_RP));
   TRY(ti89_send_key(KEY89_ENTER));
@@ -754,6 +763,8 @@ int ti89_dump_rom(const char *filename, int mask_mode)
 
       update->count = j;
       update_pbar();
+      if (update->cancel)
+	return -1;
     }
 
     TRY(cable->get(&data));
@@ -765,11 +776,8 @@ int ti89_dump_rom(const char *filename, int mask_mode)
     TRY(cable->put(0xda));
 
     update->main_percentage = (float) i / (ROMSIZE);
-    if (update->cancel) {
-	    TRY(cable->put(0xcc));        // make ROM dumping program exit.
-	    fclose(file);
-	    return -1;
-    }
+    if (update->cancel)
+      return -1;
 
     elapsed = (long) difftime(time(NULL), start);
     estimated = (long) (elapsed * (float) (1024 * 2) / i);
